@@ -8,7 +8,7 @@ use Locale::TextDomain::UTF8 'Perinci-To-Doc';
 
 extends 'Perinci::Sub::To::FuncBase';
 
-our $VERSION = '0.43'; # VERSION
+our $VERSION = '0.44'; # VERSION
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -217,14 +217,15 @@ sub after_gen_doc {
     $self->add_doc_lines(__("Return value") . ':', "");
     my $rn = $meta->{result_naked};
     $self->add_doc_lines($self->_md2pod(__(
-        "Returns an enveloped result (an array). ".
-        "First element (status) is an integer containing HTTP status code ".
-        "(200 means OK, 4xx caller error, 5xx function error). Second element ".
-        "(msg) is a string containing error message, or 'OK' if status is ".
-        "200. Third element (result) is optional, the actual result. Fourth ".
-        "element (meta) is called result metadata and is optional, a hash ".
-        "that contains extra information.")), "")
-        unless $rn;
+"Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.")))
+         unless $rn;
 
     # XXX result summary
 
@@ -246,7 +247,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-version 0.43
+version 0.44
 
 =head1 SYNOPSIS
 
